// SQLDump 1.0
// (c) Gideon Vos 2000
// admin@gideonvos.com
// Visit http://www.gideonvos.com for updates and more free components !

unit SQLDump;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, DB;

type
  TSQLDump = class(TComponent)
  private
    { Private declarations }
    FSQL:TStringList;
    FDataSet:TDataSet;
    FTableName:String;
    FStringDelim:String;
    FDateDelim:String;
    FNumericDelim:String;
    FCurrencyDelim:String;
    FGUIDDelim:String;
    FBoolDelim:String;
    function SupportedField(const TheFieldType:TFieldType):Boolean;
    function ConvertDataType(TheData:String;const TheFieldType:TFieldType):String;
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor  Destroy; override;
  published
    { Published declarations }
    property  DataSet:TDataSet       read FDataSet        write FDataSet;
    property  TableName:String       read FTableName      write FTableName;
    property  StringDelim:String     read FStringDelim    write FStringDelim;
    property  DateDelim:String       read FDateDelim      write FDateDelim;
    property  NumericDelim:String    read FNumericDelim   write FNumericDelim;
    property  CurrencyDelim:String   read FCurrencyDelim  write FCurrencyDelim;
    property  GUIDDelim:String       read FGUIDDelim      write FGUIDDelim;
    property  BoolDelim:String       read FBoolDelim      write FBoolDelim;
    property  SQL:TStringList        read FSQL;
    procedure Dump;
  end;

procedure Register;

implementation

constructor TSQLDump.Create(AOwner: TComponent);
begin
     inherited Create(AOwner);
     FSQL:=TStringList.Create;
     // Defaults Below Will Work With MS SQL Server. Adjust for MS-Access, ORACLE etc. etc.
     StringDelim:=#39; // Example: 'SomeText'
     DateDelim:=#39;   // Example: '1999-09-09';
     GUIDDelim:=#39;   // Example: '{13E74D22-1887-11D4-91BD-00C0DFEA62CD}'
end;

destructor TSQLDump.Destroy;
begin
     FSQL.Free;
     inherited Destroy;
end;

procedure TSQLDump.Dump;
var SQL:String;
    I:Integer;
begin
     FSQL.Clear;
     If FDataSet=nil Then Exit;
     If (FDataSet.Active=False) Or (FTableName='') Then Exit;
     FDataSet.First;
     While Not FDataSet.EOF Do
     Begin
          SQL:='INSERT INTO ' + FTableName + ' (';
          For I:=0 To FDataSet.FieldCount-1 Do
          Begin
               If SupportedField(FDataSet.Fields[I].DataType) Then
               Begin
                    SQL:=SQL + FDataSet.Fields[I].FieldName + ',';
               End;
          End;
          SQL:=Copy(SQL,1,Length(SQL)-1) + ') VALUES (';
          For I:=0 To FDataSet.FieldCount-1 Do
          Begin
               If SupportedField(FDataSet.Fields[I].DataType) Then
               Begin
                    SQL:=SQL + ConvertDataType(FDataSet.Fields[I].AsString,FDataSet.Fields[I].DataType) + ',';
               End;
          End;
          SQL:=Copy(SQL,1,Length(SQL)-1) + ')';
          FSQL.Add(SQL);
          FDataSet.Next;
     End;
end;

function TSQLDump.SupportedField(const TheFieldType:TFieldType):Boolean;
begin
     // Extend Supported DataTypes Here...
     Result:=False;
     Case TheFieldType Of
          ftString       : Result:=True;
          ftSmallInt     : Result:=True;
          ftInteger      : Result:=True;
          ftWord         : Result:=True;
          ftBoolean      : Result:=True;
          ftFloat        : Result:=True;
          ftCurrency     : Result:=True;
          ftBCD          : Result:=True;
          ftDate         : Result:=True;
          ftTime         : Result:=True;
          ftDateTime     : Result:=True;
          ftFixedChar    : Result:=True;
          ftWideString   : Result:=True;
          ftLargeInt     : Result:=True;
          ftGUID         : Result:=True;
     End;
end;

function TSQLDump.ConvertDataType(TheData:String;const TheFieldType:TFieldType):String;
begin
     // Extend Supported DataTypes Here...
     Case TheFieldType Of
          ftString       : Result:=FStringDelim + TheData + FStringDelim;
          ftSmallInt     : Result:=FNumericDelim + TheData + FNumericDelim;
          ftInteger      : Result:=FNumericDelim + TheData + FNumericDelim;
          ftWord         : Result:=FNumericDelim + TheData + FNumericDelim;
          ftBoolean      : Result:=FBoolDelim + TheData + FBoolDelim;
          ftFloat        : Result:=FNumericDelim + TheData + FNumericDelim;
          ftCurrency     : Result:=FCurrencyDelim + TheData + FCurrencyDelim;
          ftBCD          : Result:=FNumericDelim + TheData + FNumericDelim;
          ftDate         : Result:=FDateDelim + TheData + FDateDelim;
          ftTime         : Result:=FDateDelim + TheData + FDateDelim;
          ftDateTime     : Result:=FDateDelim + TheData + FDateDelim;
          ftFixedChar    : Result:=FStringDelim + TheData + FStringDelim;
          ftWideString   : Result:=FStringDelim + TheData + FStringDelim;
          ftLargeInt     : Result:=FNumericDelim + TheData + FNumericDelim;
          ftGUID         : Result:=FGUIDDelim + TheData + FGUIDDelim;
     End;
end;

procedure Register;
begin
     RegisterComponents('Gideon Vos', [TSQLDump]);
end;

end.
